// Chrome to Safari port
// Author: Michael Gundlach (gundlach@gmail.com)
// License: GPLv3 as part of code.getadblock.com
//          or MIT if GPLv3 conflicts with your code's license.
//
// Porting library to make Chrome extensions work in Safari.
// To use: Add as the first script loaded in your Options page,
// your background page, your Chrome manifest.json, and your
// Safari Info.plist (created by the Extensions Builder).
//
// Then you can use chrome.* APIs as usual, and check the SAFARI
// global boolean variable to see if you're in Safari or Chrome
// for doing browser-specific stuff.  The safari.* APIs will
// still be available in Safari, and the chrome.* APIs will be
// unchanged in Chrome.

'use strict';

/* For ESLint: List any global identifiers used in this file below */
/* global chrome, browser:true */

let SAFARI;
let LEGACY_SAFARI;
let LEGACY_SAFARI_51;
let Fennec;

if (typeof SAFARI === 'undefined') {
  (function safariPort() {
    // True in Safari, false in Chrome.
    SAFARI = (function safariCheck() {
      if (typeof safari === 'undefined' && typeof chrome === 'undefined') {
        // Safari bug: window.safari undefined in iframes with JS src in them.
        // Must get it from an ancestor.
        let w = window;
        while (w.safari === undefined && w !== window.top) {
          w = w.parent;
        }

        window.safari = w.safari;
      }

      return (typeof safari !== 'undefined');
    }());

    // Safari 5.0 (533.x.x) with no menu support
    LEGACY_SAFARI = SAFARI && (navigator.appVersion.match(/\sSafari\/(\d+)\./) || [null, 0])[1] < 534;

    // Safari 5.1 (534.x.x) with no undo support
    LEGACY_SAFARI_51 = SAFARI && (navigator.appVersion.match(/\sSafari\/(\d+)\./) || [null, 0])[1] <= 534;
  }());
}
// allow us to run in non-mozilla browsers
if (typeof browser === 'undefined') {
  browser = chrome;
}
const portInit = new Promise(((resolve) => {
  Fennec = false;
  if (browser.runtime && browser.runtime.getBrowserInfo) {
    const bInfo = browser.runtime.getBrowserInfo();
    bInfo.then((info) => {
      Fennec = (info && info.name === 'Fennec');
      resolve();
    });
  }
}));

// Attach methods to window
Object.assign(window, {
  Fennec,
});
